<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 06/26/2004 *
 * ===================                          Last change: 06/26/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-list_autopurge.php                          *
 * -------------------------------------------------------------------- *
 * Short description : Find inactive accounts and just list them        *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Inaktive Accounts finden und dann auflisten      *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isAdmin())) {
	die();
} // END - if

// Add description as navigation point
addYouAreHereLink('admin', __FILE__);

// Exclude default referral id if set
$userExclusionSql = ' ';
$excludedUserids = runFilterChain('config_userid_exclusion_sql', array());
if (isFilledArray($excludedUserids)) {
	// Exclude all
	$userExcludeSql = ' AND `d`.`userid` NOT IN (' . implode(', ', $excludedUserids) . ')';
} // END - if

// Check for all accounts
$result = sqlQuery("SELECT
	`d`.`userid`,
	`d`.`gender`,
	`d`.`surname`,
	`d`.`family`,
	`d`.`email`,
	`d`.`joined`,
	`d`.`last_online`,
	`d`.`ap_notified`
FROM
	`{?_MYSQL_PREFIX?}_user_data` AS `d`
WHERE
	`d`.`status`='CONFIRMED' AND
	(UNIX_TIMESTAMP() - `d`.`joined`) >= {?ap_inactive_since?} AND
	(UNIX_TIMESTAMP() - `d`.`last_online`) >= {?ap_inactive_since?} AND
	(UNIX_TIMESTAMP() - `d`.`ap_notified`) >= {?ap_inactive_since?}
	" . runFilterChain('user_exclusion_sql', ' ' . $userExcludeSql) . "
ORDER BY
	`d`.`userid` ASC", __FILE__, __LINE__);

if (!ifSqlHasZeroNums($result)) {
	// Ok, we have found some inactive accounts
	$OUT = '';
	while ($content = sqlFetchArray($result)) {
		// Prepare data for the row template
		$content = array(
			'userid'      => $content['userid'],
			'gender'      => $content['gender'],
			'surname'     => $content['surname'],
			'family'      => $content['family'],
			'email'       => '<a href="' . generateEmailLink($content['email'], 'user_data') . '">' . $content['email'] . '</a>',
			'joined'      => generateDateTime($content['joined'], 2),
			'last_online' => generateDateTime($content['last_online'], 2),
			'ap_notified' => generateDateTime($content['ap_notified'], 2),
		);

		// Load row template
		$OUT .= loadTemplate('admin_list_autopurge_row', TRUE, $content);
	} // END - while

	// Free memory
	sqlFreeResult($result);
	$content['rows'] = $OUT;

	// Load main template
	loadTemplate('admin_list_autopurge', FALSE, $content);
} else {
	// All members are active or you don't have any registered
	displayMessage('{--ADMIN_AUTOPURGE_ALL_ACTIVE--}');
}

// [EOF]
?>
