<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 11/24/2004 *
 * ===================                          Last change: 11/26/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-top10.php                                   *
 * -------------------------------------------------------------------- *
 * Short description : TOP logins / best earner etc.                    *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : TOP-Logins / Bestverdiener usw.                  *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	exit();
} // END - if

// Add description as navigation point
addYouAreHereLink('guest', __FILE__);

if ((!isExtensionActive('top10')) && (!isAdmin())) {
	displayMessage('{%pipe,generateExtensionInactiveNotInstalledMessage=top10%}');
	return;
} // END - if

// Init array
$rows = array();

// TOP logins
$result = sqlQuery("SELECT
	`userid`,
	`last_online`
FROM
	`{?_MYSQL_PREFIX?}_user_data`
WHERE
	`total_logins` > 0 AND
	`status`='CONFIRMED'
	" . runFilterChain('user_exclusion_sql', ' ') . "
ORDER BY
	`total_logins` DESC
LIMIT {?top10_max?}", __FILE__, __LINE__);

$OUT = ''; $count = 1;
while ($content = sqlFetchArray($result)) {
	// Prepare data for template
	$content = array(
		'count'        => $count,
		'userid'       => $content['userid'],
		'last_online'  => generateDateTime($content['last_online'], '3'),
	);

	// Load row template
	$OUT .= loadTemplate('guest_top10_row_login', TRUE, $content);

	// Count one up
	$count++;
} // END - while

if ($count < getTop10Max()) {
	// Add more "blank" rows
	for ($i = $count; $i <= getTop10Max(); $i++) {
		// Prepare data for template
		$content = array(
			'index' => $i
		);

		// Load row template
		$OUT .= loadTemplate('guest_top10_empty5', TRUE, $content);
	} // END - for
} // END - if

// Remember the rows in array
$rows['logins_out'] = $OUT;

// Free result
sqlFreeResult($result);

// TOP earners
$result = sqlQuery("SELECT
	`d`.`userid`,
	SUM(`p`.`points` + `p`.`locked_points`) AS `points`,
	`d`.`last_online`
FROM
	`{?_MYSQL_PREFIX?}_user_data` AS `d`
LEFT JOIN
	{?_MYSQL_PREFIX?}_user_points AS `p`
ON
	`p`.`userid`=`d`.`userid`
WHERE
	`p`.`points` > 0 AND
	`d`.`status`='CONFIRMED'
	" . runFilterChain('user_exclusion_sql', ' ') . "
GROUP BY
	`p`.`userid`
ORDER BY
	`points` DESC,
	`d`.`last_online` DESC
LIMIT {?top10_max?}", __FILE__, __LINE__);

$OUT = ''; $count = 1;
while ($content = sqlFetchArray($result)) {
	// Prepare data for template
	$content['count']       = $count;
	$content['last_online'] = generateDateTime($content['last_online'], '3');

	// Load row template
	$OUT .= loadTemplate('guest_top10_row_earner', TRUE, $content);

	// Count one up
	$count++;
} // END - while

if ($count < getTop10Max()) {
	// Add more "blank" rows
	for ($i = $count; $i <= getTop10Max(); $i++) {
		// Prepare data for template
		$content = array(
			'index' => $i
		);

		// Load row template
		$OUT .= loadTemplate('guest_top10_empty4', TRUE, $content);
	} // END - for
} // END - if

// Remember the rows in array
$rows['points_out'] = $OUT;

// Free result
sqlFreeResult($result);

// TOP referral "hunter"
$result = sqlQuery("SELECT
	`d`.`userid`,
	SUM(`r`.`counter`) AS `refs`,
	`d`.`last_online`
FROM
	`{?_MYSQL_PREFIX?}_user_data` AS `d`
LEFT JOIN
	{?_MYSQL_PREFIX?}_refsystem AS `r`
ON
	`r`.`userid`=`d`.`userid`
WHERE
	`r`.`counter` > 0 AND
	`d`.`status`='CONFIRMED'
	" . runFilterChain('user_exclusion_sql', ' ') . "
GROUP BY
	`r`.`userid`
ORDER BY
	`refs` DESC,
	`d`.`last_online` DESC
LIMIT {?top10_max?}", __FILE__, __LINE__);

$OUT = ''; $count = 1;
while ($content = sqlFetchArray($result)) {
	// Prepare data for template
	$content = array(
		'count'       => $count,
		'userid'      => $content['userid'],
		'refs'        => $content['refs'],
		'last_online' => generateDateTime($content['last_online'], '3')
	);

	// Load row template
	$OUT .= loadTemplate('guest_top10_row_refs', TRUE, $content);

	// Count one up
	$count++;
} // END - while

if ($count < getTop10Max()) {
	// Add more "blank" rows
	for ($i = $count; $i <= getTop10Max(); $i++) {
		// Prepare data for template
		$content = array(
			'index' => $i
		);

		// Load row template
		$OUT .= loadTemplate('guest_top10_empty5', TRUE, $content);
	} // END - for
} // END - if

// Remember the rows in array
$rows['referrals_out'] = $OUT;

// Free result
sqlFreeResult($result);

// Load final template
loadTemplate('guest_top10', FALSE, $rows);

// [EOF]
?>
